@@ -48,4 +48,6 @@ class ExitState:
 
     PUBLISHING_FAILED = 170
 
-    BAD_RELEASE_ID = 180
+    BAD_VERSION = 180
+    BAD_REPO = 190
+    BAD_GIT_EXE = 200
