@@ -9,9 +9,14 @@
 
 """Define flit entry points."""
 
-from .commands import main
+from .commands import main, release_flow_main
 
 
 def build_harness_entry() -> None:
     """Flit entry point to ``build-harness`` command CLI argument parsing."""
     main()
+
+
+def release_flow_entry() -> None:
+    """Flit entry point to ``release-flow`` command CLI argument parsing."""
+    release_flow_main()
