@@ -34,6 +34,10 @@ class TestPublish:
             main,
             [
                 "publish",
+                "--user",
+                "username",
+                "--password",
+                "password",
             ],
         )
 
@@ -41,7 +45,17 @@ class TestPublish:
         mock_run.assert_has_calls(
             [
                 mocker.call(
-                    ["/some/path/flit", "publish"],
+                    [
+                        "/some/path/twine",
+                        "upload",
+                        "--non-interactive",
+                        "dist/*.whl",
+                        "dist/*.tar.gz",
+                    ],
+                    env={
+                        "TWINE_PASSWORD": "password",
+                        "TWINE_USERNAME": "username",
+                    },
                 ),
             ]
         )
